/****************************************************************************
** QgsGridMakerPluginGui meta object code from reading C++ file 'plugingui.h'
**
** Created: Fri Nov 4 14:25:40 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "plugingui.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsGridMakerPluginGui::className() const
{
    return "QgsGridMakerPluginGui";
}

QMetaObject *QgsGridMakerPluginGui::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsGridMakerPluginGui( "QgsGridMakerPluginGui", &QgsGridMakerPluginGui::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsGridMakerPluginGui::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsGridMakerPluginGui", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsGridMakerPluginGui::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsGridMakerPluginGui", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsGridMakerPluginGui::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QgsGridMakerPluginGuiBase::staticMetaObject();
    static const QUParameter param_signal_0[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod signal_0 = {"drawRasterLayer", 1, param_signal_0 };
    static const QUParameter param_signal_1[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In },
	{ 0, &static_QUType_QString, 0, QUParameter::In },
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod signal_1 = {"drawVectorLayer", 3, param_signal_1 };
    static const QMetaData signal_tbl[] = {
	{ "drawRasterLayer(QString)", &signal_0, QMetaData::Private },
	{ "drawVectorLayer(QString,QString,QString)", &signal_1, QMetaData::Private }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsGridMakerPluginGui", parentObject,
	0, 0,
	signal_tbl, 2,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsGridMakerPluginGui.setMetaObject( metaObj );
    return metaObj;
}

void* QgsGridMakerPluginGui::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsGridMakerPluginGui" ) )
	return this;
    return QgsGridMakerPluginGuiBase::qt_cast( clname );
}

// SIGNAL drawRasterLayer
void QgsGridMakerPluginGui::drawRasterLayer( QString t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 0, t0 );
}

#include <qobjectdefs.h>
#include <qsignalslotimp.h>

// SIGNAL drawVectorLayer
void QgsGridMakerPluginGui::drawVectorLayer( QString t0, QString t1, QString t2 )
{
    if ( signalsBlocked() )
	return;
    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 1 );
    if ( !clist )
	return;
    QUObject o[4];
    static_QUType_QString.set(o+1,t0);
    static_QUType_QString.set(o+2,t1);
    static_QUType_QString.set(o+3,t2);
    activate_signal( clist, o );
}

bool QgsGridMakerPluginGui::qt_invoke( int _id, QUObject* _o )
{
    return QgsGridMakerPluginGuiBase::qt_invoke(_id,_o);
}

bool QgsGridMakerPluginGui::qt_emit( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->signalOffset() ) {
    case 0: drawRasterLayer((QString)static_QUType_QString.get(_o+1)); break;
    case 1: drawVectorLayer((QString)static_QUType_QString.get(_o+1),(QString)static_QUType_QString.get(_o+2),(QString)static_QUType_QString.get(_o+3)); break;
    default:
	return QgsGridMakerPluginGuiBase::qt_emit(_id,_o);
    }
    return TRUE;
}
#ifndef QT_NO_PROPERTIES

bool QgsGridMakerPluginGui::qt_property( int id, int f, QVariant* v)
{
    return QgsGridMakerPluginGuiBase::qt_property( id, f, v);
}

bool QgsGridMakerPluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
